@@ -50,10 +50,10 @@ QString Result::toLatex()
 {
     QString html=toHtml();
     //replace linebreaks
-    html.replace(QRegExp(QLatin1String("<br/>[\n]")), QLatin1String("\n"));
+    html.replace(QRegExp(QLatin1String("<br/>[\n]")), QStringLiteral("\n"));
     //remove all the unknown tags
     html.remove( QRegExp( QLatin1String("<[a-zA-Z\\/][^>]*>") ) );
-    return QString::fromLatin1("\\begin{verbatim} %1 \\end{verbatim}").arg(html);
+    return QStringLiteral("\\begin{verbatim} %1 \\end{verbatim}").arg(html);
 }
 
 void Result::saveAdditionalData(KZip* archive)
