@@ -105,6 +105,14 @@ Worksheet::~Worksheet()
     m_firstEntry = nullptr;
     if (m_loginDone)
         m_session->logout();
+    if (m_session)
+    {
+        disconnect(m_session, 0, 0, 0);
+        if (m_session->status() != Cantor::Session::Disable)
+            m_session->logout();
+        m_session->deleteLater();
+        m_session = nullptr;
+    }
 }
 
 void Worksheet::loginToSession()
@@ -514,7 +522,7 @@ void Worksheet::showCompletion()
         current->showCompletion();
 }
 
-WorksheetEntry* Worksheet::appendEntry(const int type)
+WorksheetEntry* Worksheet::appendEntry(const int type, bool focus)
 {
     WorksheetEntry* entry = WorksheetEntry::create(type, this);
 
@@ -528,8 +536,11 @@ WorksheetEntry* Worksheet::appendEntry(const int type)
             setFirstEntry(entry);
         setLastEntry(entry);
         updateLayout();
-        makeVisible(entry);
-        focusEntry(entry);
+        if (focus)
+        {
+            makeVisible(entry);
+            focusEntry(entry);
+        }
         emit modified();
     }
     return entry;
@@ -1107,30 +1118,31 @@ bool Worksheet::load(QIODevice* device)
     WorksheetEntry* entry = nullptr;
     while (!expressionChild.isNull()) {
         QString tag = expressionChild.tagName();
+        // Don't add focus on load
         if (tag == QLatin1String("Expression"))
         {
-            entry = appendCommandEntry();
+            entry = appendEntry(CommandEntry::Type, false);
             entry->setContent(expressionChild, file);
         } else if (tag == QLatin1String("Text"))
         {
-            entry = appendTextEntry();
+            entry = appendEntry(TextEntry::Type, false);
             entry->setContent(expressionChild, file);
         } else if (tag == QLatin1String("Markdown"))
         {
-            entry = appendMarkdownEntry();
+            entry = appendEntry(MarkdownEntry::Type, false);
             entry->setContent(expressionChild, file);
         } else if (tag == QLatin1String("Latex"))
         {
-            entry = appendLatexEntry();
+            entry = appendEntry(LatexEntry::Type, false);
             entry->setContent(expressionChild, file);
         } else if (tag == QLatin1String("PageBreak"))
         {
-            entry = appendPageBreakEntry();
+            entry = appendEntry(PageBreakEntry::Type, false);
             entry->setContent(expressionChild, file);
         }
         else if (tag == QLatin1String("Image"))
         {
-            entry = appendImageEntry();
+            entry = appendEntry(ImageEntry::Type, false);
             entry->setContent(expressionChild, file);
         }
 
